from setuptools import setup

version = "0.0.3"
short_description="A comprehensive useless package."

def readme():
    with open('README.md') as f:
        README = f.read()
    return README

setup(name="pacchettoDiG",
      version=version,
      description= short_description,
      long_description=readme(),
      long_description_content_type="text/markdown",
      author="Gabriele Pittarello",
      license="BSD 3-Clause",
      classifiers=[
          "Development Status :: 3 - Alpha",
          "License :: OSI Approved :: BSD License",
          "Programming Language :: Python",
          "Operating System :: Unix",
          "Operating System :: MacOS :: MacOS X",
          "Operating System :: Microsoft :: Windows",
      ],
      py_modules=["module1","module2","__init__"],
      packages=["pacchettodig"],
      include_package_data=True,
      install_requires=["twiggy", "numpy>=1.21.4", "matplotlib>=3.5.0","scipy>=1.7.2"],
      project_urls={
          'Source Code': 'https://github.com/GEM-analytics'
      }
      )


__version__= "0.0.3"
__doc__= "Useless string"



import sys
from twiggy import quick_setup,log
import numpy as np
from scipy import stats
from scipy.special import factorial
import matplotlib.pyplot as plt
import matplotlib.pyplot as plt
from scipy.fft import fft, ifft
from pckg.module2 import *
from pckg.module1 import *

quick_setup()
logger= log.name('lossaggregation')
